@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 my %SERIALIZERS = (
-    json     => 'Raisin::Plugin::Format::JSON',
-    json_rpc => 'Raisin::Plugin::Format::JSON',
-    yaml     => 'Raisin::Plugin::Format::YAML',
-    yml      => 'Raisin::Plugin::Format::YAML',
+    json     => 'json',
+    json_rpc => 'json',
+    yaml     => 'yaml',
+    yml      => 'yaml',
 );
 
 sub detect_serializer {
@@ -32,6 +32,6 @@ Raisin::Utils - Utility subroutine for Raisin.
 
 =head2 detect_serializer
 
-Detect serializer by content type.
+Detect serializer by content type or extension.
 
 =cut
